@@ -1,4 +1,4 @@
-//@line 42 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/browser/components/feeds/src/FeedWriter.js"
+//@line 42 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/browser/components/feeds/src/FeedWriter.js"
 
 const Cc = Components.classes;
 const Ci = Components.interfaces;
@@ -641,7 +641,7 @@ FeedWriter.prototype = {
    * @returns The display name of the application represented by the file.
    */
   _getFileDisplayName: function FW__getFileDisplayName(file) {
-//@line 702 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/browser/components/feeds/src/FeedWriter.js"
+//@line 702 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/browser/components/feeds/src/FeedWriter.js"
     var ios = 
         Cc["@mozilla.org/network/io-service;1"].
         getService(Ci.nsIIOService);
@@ -699,9 +699,9 @@ FeedWriter.prototype = {
           // XXXben - we need to compare this with the running instance executable
           //          just don't know how to do that via script...
           // XXXmano TBD: can probably add this to nsIShellService
-//@line 765 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/browser/components/feeds/src/FeedWriter.js"
+//@line 765 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/browser/components/feeds/src/FeedWriter.js"
           if (fp.file.leafName != "firefox-bin") {
-//@line 768 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/browser/components/feeds/src/FeedWriter.js"
+//@line 768 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/browser/components/feeds/src/FeedWriter.js"
             this._initMenuItemWithFile(this._contentSandbox.selectedAppMenuItem,
                                        this._selectedApp);
 
@@ -782,8 +782,6 @@ FeedWriter.prototype = {
 
   // nsIDomEventListener
   handleEvent: function(event) {
-    // see comments in init()
-    event = new XPCNativeWrapper(event);
     if (event.target.ownerDocument != this._document) {
       LOG("FeedWriter.handleEvent: Someone passed the feed writer as a listener to the events of another document!");
       return;
@@ -1089,10 +1087,7 @@ FeedWriter.prototype = {
 
   // nsIFeedWriter
   init: function FW_init(aWindow) {
-    // Explicitly wrap |window| in an XPCNativeWrapper to make sure
-    // it's a real native object! This will throw an exception if we
-    // get a non-native object.
-    var window = new XPCNativeWrapper(aWindow);
+    var window = aWindow;
     this._feedURI = this._getOriginalURI(window);
     if (!this._feedURI)
       return;
@@ -1203,7 +1198,7 @@ FeedWriter.prototype = {
     var selectedItem = this._getSelectedItemFromMenulist(handlersMenuList);
 
     // Show the file picker before subscribing if the
-    // choose application menuitem was choosen using the keyboard
+    // choose application menuitem was chosen using the keyboard
     if (selectedItem.id == "chooseApplicationMenuItem") {
       if (!this._chooseClientApp())
         return;
@@ -1269,9 +1264,6 @@ FeedWriter.prototype = {
 
   // nsIObserver
   observe: function FW_observe(subject, topic, data) {
-    // see init()
-    subject = new XPCNativeWrapper(subject);
-    
     if (!this._window) {
       // this._window is null unless this.init was called with a trusted
       // window object.
@@ -1338,9 +1330,6 @@ FeedWriter.prototype = {
 
    // nsINavHistoryService
    onPageChanged: function FW_onPageChanged(aURI, aWhat, aValue) {
-     // see init()
-     aURI = new XPCNativeWrapper(aURI);
-
      if (aWhat == Ci.nsINavHistoryObserver.ATTRIBUTE_FAVICON) {
        // Go through the readers menu and look for the corresponding
        // reader menu-item for the page if any.
@@ -1360,6 +1349,7 @@ FeedWriter.prototype = {
    onEndUpdateBatch: function() { },
    onVisit: function() { },
    onTitleChanged: function() { },
+   onBeforeDeleteURI: function() { },
    onDeleteURI: function() { },
    onClearHistory: function() { },
    onPageExpired: function() { },
