@@ -715,6 +715,7 @@ pref("network.IDN.whitelist.es", true);
 pref("network.IDN.whitelist.fi", true);
 pref("network.IDN.whitelist.gr", true);
 pref("network.IDN.whitelist.hu", true);
+pref("network.IDN.whitelist.il", true);
 pref("network.IDN.whitelist.io", true);
 pref("network.IDN.whitelist.ir", true);
 pref("network.IDN.whitelist.is", true);
@@ -748,6 +749,8 @@ pref("network.IDN.whitelist.xn--mgba3a4f16a", true);
 pref("network.IDN.whitelist.xn--mgba3a4fra", true);
 // jo, Jordan, .<Al-Ordon>
 pref("network.IDN.whitelist.xn--mgbayh7gpa", true);
+// qa, Qatar, .<Qatar>
+pref("network.IDN.whitelist.xn--wgbl6a", true);
 // ru, Russian Federation, .<RF>
 pref("network.IDN.whitelist.xn--p1ai", true);
 // sa, Saudi Arabia, .<al-Saudiah> with variants
@@ -845,7 +848,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 869 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 872 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
 // Controls which NTLM authentication implementation we default to. True forces
 // the use of our generic (internal) NTLM authentication implementation vs. any
@@ -1266,15 +1269,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1687 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 1690 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2111 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2114 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2314 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
-
-//@line 2410 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2317 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
 //@line 2413 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+
+//@line 2416 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1544,20 +1547,20 @@ pref("ui.panel.default_level_parent", true);
 
 pref("mousewheel.system_scroll_override_on_root_content.enabled", false);
 
-//@line 2685 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2688 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2753 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2756 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2779 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2782 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2799 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2802 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2801 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2804 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
 pref("print.postscript.print_command", "lp -c -s ${MOZ_PRINTER_NAME:+-d\"$MOZ_PRINTER_NAME\"}");
 pref("print.print_command", "lp -c -s ${MOZ_PRINTER_NAME:+-d\"$MOZ_PRINTER_NAME\"}");
 
-//@line 2807 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2810 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1594,9 +1597,9 @@ pref("image.cache.timeweight", 500);
 // The default Accept header sent for images loaded over HTTP(S)
 pref("image.http.accept", "image/png,image/*;q=0.8,*/*;q=0.5");
 
-//@line 2849 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2852 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2854 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2857 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
